LLM Vulnerability Scanner

#### 🚀 NEW: Star Landalf on Github 🚀

Docs
Github I

### Agentic LLM Vulnerability Scanner [Beta]

Input the API LLM spec and specify the maximum budget in tokens.

Select a config
{{ config.name }}
{{config.customInstructions || 'Requires API key'}}
API
LLM API Spec, PROMPT variable will be replaced with the testing prompt
Maximum Budget in {{budget}}M Tokens
{{ package.dataset_name }}
{{ package.source || 'Local dataset' }}
{{ package.num_prompts.toLocaleString() }} prompts
Dynamic dataset
Oops! {{errorMsg}}
> {{okMsg}}

### Scan Results

Vulnerability Module | % Protection rate | Number of Tokens | Cost (in gpt-3 tokens)
--- | --- | --- | ---
{{result.module}} | {{(100 - result.failureRate).toFixed(2)}} | {{result.tokens}}k | ${{result.cost.toFixed(2)}}